@@ -17,6 +17,18 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Play John Horton Conway\'s Game of Life, hopefully faster than a naive implementation.';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db xt/author/optionals } ];
+}
+
+sub author {
+    return 'Thomas R. Wyant, III F<wyant at cpan dot org>';
+}
+
 sub build_requires {
     return +{
 	'Test2::V0'			=> 0,
@@ -25,11 +37,27 @@ sub build_requires {
     };
 }
 
+sub configure_requires {
+    return +{
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Game-Life-Faster';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
     my ( undef, @extra ) = @_;
     return {
@@ -39,7 +67,8 @@ sub meta_merge {
 	dynamic_config	=> 1,
 	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://github.com/trwyant/perl-Game-Life-Faster/issues',
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Game-Life-Faster',
+		# web	=> 'https://github.com/trwyant/perl-Game-Life-Faster/issues',
 		mailto  => 'wyant@cpan.org',
 	    },
 	    license	=> 'http://dev.perl.org/licenses/',
@@ -53,6 +82,20 @@ sub meta_merge {
     };
 }
 
+sub module_name {
+    return 'Game::Life::Faster';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'xt',
+                   ],
+    };
+}
+
 sub provides {
     -d 'lib'
 	or return;
@@ -71,6 +114,7 @@ sub requires {
     return +{
 	'Carp'		=> 0,
 	'List::Util'	=> 0,
+	constant	=> 0,
 	strict		=> 0,
 	warnings	=> 0,
 	@extra,
@@ -81,6 +125,15 @@ sub requires_perl {
     return 5.008001;
 }
 
+sub script_files {
+    return [ qw{
+	script/game-life-faster
+	} ];
+}
+
+sub version_from {
+    return 'lib/Game/Life/Faster.pm';
+}
 
 1;
 
@@ -115,6 +168,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use YAML;
@@ -125,6 +191,20 @@ modules required to build the C<Game::Life::Faster> package, suitable for
 use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -136,6 +216,32 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
+=head2 meta_merge
+
+ use YAML;
+ print Dump( $meta->meta_merge() );
+
+This method returns a reference to a hash describing the meta-data which
+has to be provided by making use of the builder's C<meta_merge>
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
+
+Any arguments will be appended to the generated array.
+
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
 =head2 provides
 
  use YAML;
@@ -165,11 +271,20 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -178,10 +293,10 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Game-Life-Faster>,
 L<https://github.com/trwyant/perl-Game-Life-Faster/issues>, or in
 electronic mail to the author.
 
